@@ -408,14 +408,17 @@ struct qp_option options[] =
 { {0,1}, "--shell",              "-e", 0,         "run a Quickplot command shell that reads commands from "
                                                   "standard input and writes out to standard output.  The "
                                                   "default is no shell and standard input will be read as "
-                                                  "graph data.  You may use ::--no-pipe@@ to stop standard "
+                                                  "graph data.  If Quickplot is reading standard input for "
+                                                  "plot data Quickplot will read shell commands "
+                                                  "from the controlling terminal (/dev/tty) after all the "
+                                                  "standard input has been read.  "
+                                                  "You may use ::--no-pipe@@ to stop standard "
                                                   "input from being read as graph data.  The shell can do "
                                                   "most all the things that command-line options can do and "
                                                   "a lot more.  Run an interactive shell with ::quickplot "
                                                   "--shell@@ and use the help and tab completion to see how "
-                                                  "it works.  You can also "
-                                                  "connect a Quickplot command shell to a "
-                                                  "running Quickplot program with the program "
+                                                  "it works.  You can also connect a Quickplot command "
+                                                  "shell to a running Quickplot program with the program "
                                                   "::quickplot_shell@@.",                                     "NULL",     "struct "
                                                                                                                           "qp_shell"
                                                                                                                           " *"        },
